@@ -5,10 +5,10 @@ from scanapi.exit_code import ExitCode
 
 
 class Session:
-    """ Class that handles each scanapi session. """
+    """Class that handles each scanapi session."""
 
     def __init__(self):
-        """ Constructs a Session object. """
+        """Constructs a Session object."""
         self.successes = 0
         self.failures = 0
         self.errors = 0
@@ -17,11 +17,14 @@ class Session:
 
     @property
     def succeed(self):
-        """ Property decorated method that returns success (no errors or failures. """
+        """
+        Property decorated method that returns if there were no no errors or
+        failures.
+        """
         return self.errors == 0 and self.failures == 0
 
     def exit(self):
-        """ Handles the exiting of the Session """
+        """Handles the exiting of the Session."""
         if self.errors:
             sys.exit(ExitCode.TESTS_ERROR)
 
@@ -31,19 +34,19 @@ class Session:
         sys.exit(self.exit_code)
 
     def increment_successes(self):
-        """ Increments success count. """
+        """Increments success count."""
         self.successes += 1
 
     def increment_failures(self):
-        """ Increments failure count. """
+        """Increments failure count."""
         self.failures += 1
 
     def increment_errors(self):
-        """ Increments error count. """
+        """Increments error count."""
         self.errors += 1
 
     def elapsed_time(self):
-        """ Returns the delta of time since session object started. """
+        """Returns the delta of time since session object started."""
         return datetime.now() - self.started_at
 
 
